@@ -2,17 +2,17 @@
  * Copyright (C) 2005, 2007, 2008 g10 Code GmbH
  *
  * This file is part of GpgOL.
- * 
+ *
  * GpgOL is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
  * version 2.1 of the License, or (at your option) any later version.
- * 
+ *
  * GpgOL is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
@@ -75,8 +75,8 @@ char *mapi_get_body (LPMESSAGE message, size_t *r_nbytes);
 
 mapi_attach_item_t *mapi_create_attach_table (LPMESSAGE message, int fast);
 void mapi_release_attach_table (mapi_attach_item_t *table);
-LPSTREAM mapi_get_attach_as_stream (LPMESSAGE message, 
-                                    mapi_attach_item_t *item, 
+LPSTREAM mapi_get_attach_as_stream (LPMESSAGE message,
+                                    mapi_attach_item_t *item,
                                     LPATTACH *r_attach);
 char *mapi_get_attach (LPMESSAGE message,
                        mapi_attach_item_t *item, size_t *r_nbytes);
@@ -96,7 +96,7 @@ int  mapi_test_attach_hidden (LPATTACH attach);
 
 char *mapi_get_mime_info (LPMESSAGE msg);
 
-char *mapi_get_message_content_type (LPMESSAGE message, 
+char *mapi_get_message_content_type (LPMESSAGE message,
                                      char **r_protocol, char **r_smtype);
 
 int   mapi_has_last_decrypted (LPMESSAGE message);
@@ -133,12 +133,17 @@ void mapi_set_mesage_class (LPMESSAGE message, const char *cls);
 /* Parse the headers for additional useful fields.
 
   r_autocrypt_info: Information about the autocrypt header.
+  r_header_info: Just a generic struct for other stuff.
 
   A return value of false indicates an error. Check the
   individual info fields "exists" values to check if
   the header exists in the message */
 bool mapi_get_header_info (LPMESSAGE message,
-                           autocrypt_s &r_autocrypt_info);
+                           header_info_s &r_header_info);
 std::string mapi_get_header (LPMESSAGE message);
+
+/* Set the content type of a message in transport headers.
+   a value of null for ct removes the content type. */
+int mapi_set_content_type (LPMESSAGE message, const char *ct);
 #endif
 #endif /*MAPIHELP_H*/
