@@ -558,8 +558,8 @@ write_plain (sink_t sink, const void *data, size_t datalen)
 }
 
 
-/* Infer the conent type from the FILENAME.  The return value is
-   a static string there won't be an error return.  In case Bae 64
+/* Infer the content type from the FILENAME.  The return value is
+   a static string there won't be an error return.  In case Base 64
    encoding is required for the type true will be stored at FORCE_B64;
    however, this is only a shortcut and if that is not set, the caller
    should infer the encoding by other means. */
@@ -822,7 +822,7 @@ infer_content_encoding (const void *data, size_t datalen)
    is the subset of RFC2047 outlook likes.
    Return value needs to be freed.
    */
-static char *
+char *
 utf8_to_rfc2047b (const char *input)
 {
   char *ret,
@@ -837,8 +837,6 @@ utf8_to_rfc2047b (const char *input)
     {
       return xstrdup (input);
     }
-  log_debug ("%s:%s: Encoding attachment filename. With: %s ",
-             SRCNAME, __func__, inferred_encoding == 2 ? "Base64" : "QP");
 
   if (inferred_encoding == 2)
     {
@@ -875,7 +873,8 @@ utf8_to_rfc2047b (const char *input)
 static int
 write_part (sink_t sink, const char *data, size_t datalen,
             const char *boundary, const char *filename, int is_mapibody,
-            const char *content_id = NULL)
+            const char *content_id = nullptr,
+            const char *added_headers = nullptr)
 {
   int rc;
   const char *ct;
@@ -969,6 +968,15 @@ write_part (sink_t sink, const char *data, size_t datalen,
                                NULL)))
       return rc;
 
+  /* Add any injected additional headers */
+  if (added_headers)
+    {
+      if ((rc = write_multistring (sink, added_headers, nullptr)))
+        {
+          return rc;
+        }
+    }
+
   xfree(encoded_filename);
 
   /* Write delimiter.  */
@@ -1393,7 +1401,9 @@ add_body (Mail *mail, const char *boundary, sink_t sink,
       if (plain_body)
         {
           rc = write_part (sink, plain_body, strlen (plain_body),
-                           boundary, NULL, 1);
+                           boundary, NULL, 1, nullptr,
+                           mail ? mail->protectedHeaders ().c_str () :
+                           nullptr);
         }
       /* Just the plain body or no body. We are done. */
       return rc;
@@ -1422,7 +1432,9 @@ add_body (Mail *mail, const char *boundary, sink_t sink,
 
   /* Now the plain body part */
   if ((rc = write_part (sink, plain_body, strlen (plain_body),
-                       alt_boundary, NULL, 1)))
+                       alt_boundary, NULL, 1, nullptr,
+                       mail ? mail->protectedHeaders().c_str() :
+                       nullptr)))
     {
       TRACEPOINT;
       return rc;
